Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'jpa/plugins/org.eclipse.jpt.jpa.core/src/org/eclipse/jpt/jpa/core/context/persistence/PersistenceUnit.java')
-rw-r--r--jpa/plugins/org.eclipse.jpt.jpa.core/src/org/eclipse/jpt/jpa/core/context/persistence/PersistenceUnit.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/jpa/plugins/org.eclipse.jpt.jpa.core/src/org/eclipse/jpt/jpa/core/context/persistence/PersistenceUnit.java b/jpa/plugins/org.eclipse.jpt.jpa.core/src/org/eclipse/jpt/jpa/core/context/persistence/PersistenceUnit.java
index 670a90a2dc..71bc08cf33 100644
--- a/jpa/plugins/org.eclipse.jpt.jpa.core/src/org/eclipse/jpt/jpa/core/context/persistence/PersistenceUnit.java
+++ b/jpa/plugins/org.eclipse.jpt.jpa.core/src/org/eclipse/jpt/jpa/core/context/persistence/PersistenceUnit.java
@@ -753,11 +753,11 @@ public interface PersistenceUnit
XmlPersistenceUnit getXmlPersistenceUnit();
/**
* Return whether the persistence unit specifies a persistent type with the
* specified name (i.e. the type is listed either in the persistence unit's
* list of specified classes or in one of the persistent unit's mapping files).
*/
- boolean specifiesPersistentType(String typeName);
+ boolean specifiesManagedType(String typeName);
/**
* Return the persistence unit's Java persistent types, as specified by
@@ -753,11 +753,11 @@ public interface PersistenceUnit
XmlPersistenceUnit getXmlPersistenceUnit();
/**
- * Return whether the persistence unit specifies a persistent type with the
+ * Return whether the persistence unit specifies a managed type with the
* specified name (i.e. the type is listed either in the persistence unit's
* list of specified classes or in one of the persistent unit's mapping files).

Back to the top